@@ -13,6 +13,7 @@ import ct.wrappedos
 import ct.utils
 import ct.git_utils
 
+
 def extract_value_from_argv(key, argv=None, default=None, verbose=0):
     """ Extract the value for the given key from the argv.
         Return the given default if no key was identified
@@ -22,13 +23,13 @@ def extract_value_from_argv(key, argv=None, default=None, verbose=0):
 
     value = default
 
-    hyphens = ('-','--')
+    hyphens = ("-", "--")
     for hh in hyphens:
         for arg in argv:
             try:
-                keywithhyphens = "".join([hh, key, '='])
+                keywithhyphens = "".join([hh, key, "="])
                 if keywithhyphens in arg:
-                    value = arg.split('=')[1]
+                    value = arg.split("=")[1]
                 else:
                     keywithhyphens = "".join([hh, key])
                     if keywithhyphens in arg:
@@ -36,61 +37,63 @@ def extract_value_from_argv(key, argv=None, default=None, verbose=0):
                         value = argv[index + 1]
             except ValueError:
                 pass
-        
-    if verbose >= 4: 
-        msg = 'argv extraction: ' + key + ' '
+
+    if verbose >= 4:
+        msg = "argv extraction: " + key + " "
         if value:
             msg += str(value)
-        print(msg) 
+        print(msg)
     return value
 
 
 def extract_item_from_ct_conf(
-        key,
-        user_config_dir=None,
-        system_config_dir=None,
-        exedir=None,
-        default=None,
-        verbose=0):
+    key,
+    user_config_dir=None,
+    system_config_dir=None,
+    exedir=None,
+    default=None,
+    verbose=0,
+):
     """ Extract the value for the given key from the ct.conf files.
         Return the given default if no key was identified
     """
     fileparser = CfgFileParser()
-    for cfgpath in reversed(defaultconfigs(user_config_dir=user_config_dir,
-                                  system_config_dir=system_config_dir,
-                                  exedir=exedir)):
+    for cfgpath in reversed(
+        defaultconfigs(
+            user_config_dir=user_config_dir,
+            system_config_dir=system_config_dir,
+            exedir=exedir,
+        )
+    ):
         with open(cfgpath) as cfg:
             items = fileparser.parse(cfg)
             try:
                 value = items[key]
                 if verbose >= 2:
-                    print(" ".join([cfgpath, 'contains', key, '=', value]))
+                    print(" ".join([cfgpath, "contains", key, "=", value]))
                 return value
             except KeyError:
                 continue
 
     return default
 
+
 def removedotconf(config):
-    if config[-5:] == '.conf':
+    if config[-5:] == ".conf":
         return config[:-5]
     else:
         return config
 
+
 def extractconfig(argv):
     config = None
-    config = extract_value_from_argv(
-        key='config',
-        argv=argv,
-        default=None)
+    config = extract_value_from_argv(key="config", argv=argv, default=None)
 
     if not config:
-        config = extract_value_from_argv(
-            key='c',
-            argv=argv,
-            default=None)
+        config = extract_value_from_argv(key="c", argv=argv, default=None)
     return config
 
+
 def impliedvariant(argv):
     """ If the user specified a config directly then we imply the variant name """
     config = extractconfig(argv)
@@ -102,11 +105,8 @@ def impliedvariant(argv):
 
 
 def extract_variant(
-        argv=None,
-        user_config_dir=None,
-        system_config_dir=None,
-        exedir=None,
-        verbose=0):
+    argv=None, user_config_dir=None, system_config_dir=None, exedir=None, verbose=0
+):
     """ The variant argument is parsed directly from the command line arguments
         so that it can be used to specify the default config for configargparse.
         The ct.conf files are also checked.
@@ -129,11 +129,12 @@ def extract_variant(
     # then use that as the default config file for configargparse.
     # Be careful to make use of the variant aliaes defined in the ct.conf files
     variantaliases = extract_item_from_ct_conf(
-        key='variantaliases',
+        key="variantaliases",
         user_config_dir=user_config_dir,
         system_config_dir=system_config_dir,
         exedir=exedir,
-        verbose=verbose)
+        verbose=verbose,
+    )
     if variantaliases is None:
         variantaliases = {}
     else:
@@ -141,26 +142,24 @@ def extract_variant(
 
     variant = "debug"
     variant = extract_item_from_ct_conf(
-        key='variant',
+        key="variant",
         user_config_dir=user_config_dir,
         system_config_dir=system_config_dir,
         exedir=exedir,
         default=variant,
-        verbose=verbose)
+        verbose=verbose,
+    )
     try:
-        variant = os.environ['variant']
+        variant = os.environ["variant"]
     except:
         pass
-    variant = extract_value_from_argv(
-        key='variant',
-        argv=argv,
-        default=variant)
+    variant = extract_value_from_argv(key="variant", argv=argv, default=variant)
 
     try:
         result = variantaliases[variant]
     except KeyError:
         result = variant
-    
+
     if verbose >= 4:
         print("Extract variant: " + result)
 
@@ -168,11 +167,8 @@ def extract_variant(
 
 
 def default_config_directories(
-        user_config_dir=None,
-        system_config_dir=None,
-        exedir=None,
-        repoonly=False,
-        verbose=0):
+    user_config_dir=None, system_config_dir=None, exedir=None, repoonly=False, verbose=0
+):
     # Use configuration in the order (lowest to highest priority)
     # If repoonly is true, start the procedure at step 4
     # 1) same path as exe,
@@ -187,24 +183,26 @@ def default_config_directories(
 
     # These variables are settable to assist writing tests
     if user_config_dir is None:
-        user_config_dir = appdirs.user_config_dir(appname='ct')
+        user_config_dir = appdirs.user_config_dir(appname="ct")
 
     system_dirs = []
     if system_config_dir is not None:
         system_dirs.append(system_config_dir)
     else:
         for python_config_dir in sys.path[::-1]:
-            trialpath = os.path.join(python_config_dir, 'etc/xdg/ct')
+            trialpath = os.path.join(python_config_dir, "etc/xdg/ct")
             if ct.wrappedos.isdir(trialpath) and trialpath not in system_dirs:
                 system_dirs.append(trialpath)
-        system_dirs.append(appdirs.site_config_dir(appname='ct'))
+        system_dirs.append(appdirs.site_config_dir(appname="ct"))
 
     if exedir is None:
         exedir = ct.wrappedos.dirname(ct.wrappedos.realpath(sys.argv[0]))
 
     executable_config_dir = os.path.join(exedir, "ct.conf.d")
     gitroot = ct.git_utils.find_git_root()
-    results = ct.utils.OrderedSet([os.getcwd(), gitroot, os.path.join(gitroot,'ct.conf.d')])
+    results = ct.utils.OrderedSet(
+        [os.getcwd(), gitroot, os.path.join(gitroot, "ct.conf.d")]
+    )
     if not repoonly:
         results.append([user_config_dir] + system_dirs + [executable_config_dir])
     if verbose >= 9:
@@ -214,19 +212,20 @@ def default_config_directories(
 
 
 def defaultconfigs(
-        user_config_dir=None,
-        system_config_dir=None,
-        exedir=None,
-        verbose=0):
-    ''' Find the ct.conf files '''
+    user_config_dir=None, system_config_dir=None, exedir=None, verbose=0
+):
+    """ Find the ct.conf files """
     ctconfs = [
-        os.path.join(
-            defaultdir,
-            'ct.conf') for defaultdir in reversed(default_config_directories(
-            user_config_dir=user_config_dir,
-            system_config_dir=system_config_dir,
-            exedir=exedir,
-            verbose=verbose))]
+        os.path.join(defaultdir, "ct.conf")
+        for defaultdir in reversed(
+            default_config_directories(
+                user_config_dir=user_config_dir,
+                system_config_dir=system_config_dir,
+                exedir=exedir,
+                verbose=verbose,
+            )
+        )
+    ]
 
     # Only return the configs that exist
     configs = [cfg for cfg in ctconfs if ct.wrappedos.isfile(cfg)]
@@ -236,26 +235,29 @@ def defaultconfigs(
 
 
 def config_files_from_variant(
-        variant=None,
-        argv=None,
-        user_config_dir=None,
-        system_config_dir=None,
-        exedir=None,
-        verbose=0):
+    variant=None,
+    argv=None,
+    user_config_dir=None,
+    system_config_dir=None,
+    exedir=None,
+    verbose=0,
+):
     if variant is None:
         variant = extract_variant(
-                      argv,
-                      user_config_dir=user_config_dir,
-                      system_config_dir=system_config_dir,
-                      exedir=exedir,
-                      verbose=verbose)
-    
+            argv,
+            user_config_dir=user_config_dir,
+            system_config_dir=system_config_dir,
+            exedir=exedir,
+            verbose=verbose,
+        )
+
     # Start with the default ct.conf files
     variantconfigs = defaultconfigs(
-                         user_config_dir=user_config_dir,
-                         system_config_dir=system_config_dir,
-                         exedir=exedir,
-                         verbose=verbose)
+        user_config_dir=user_config_dir,
+        system_config_dir=system_config_dir,
+        exedir=exedir,
+        verbose=verbose,
+    )
 
     # If a config file was specified directly then use that
     argvconfig = extractconfig(argv)
@@ -263,22 +265,26 @@ def config_files_from_variant(
         variantconfigs.append(argvconfig)
     else:
         # Otherwise look for a file called variant or variant.conf
-        for ext in ("",".conf"):
+        for ext in ("", ".conf"):
             variantconfigs += [
-                os.path.join(
-                    defaultdir,
-                    variant) +
-                ext for defaultdir in reversed(default_config_directories(
-                    user_config_dir=user_config_dir,
-                    system_config_dir=system_config_dir,
-                    exedir=exedir,
-                    verbose=verbose))]
+                os.path.join(defaultdir, variant) + ext
+                for defaultdir in reversed(
+                    default_config_directories(
+                        user_config_dir=user_config_dir,
+                        system_config_dir=system_config_dir,
+                        exedir=exedir,
+                        verbose=verbose,
+                    )
+                )
+            ]
 
     # Check that a config file exists for the specified variant
     if not any([ct.wrappedos.isfile(cfg) for cfg in variantconfigs]):
-        sys.stderr.write(" ".join(["Could not find a config file for variant =",variant,"\n"]))
+        sys.stderr.write(
+            " ".join(["Could not find a config file for variant =", variant, "\n"])
+        )
         sys.stderr.write("\n".join(["Checked for "] + variantconfigs))
-        sys.exit(1)        
+        sys.exit(1)
 
     # Only return the configs that exist
     configs = [cfg for cfg in variantconfigs if ct.wrappedos.isfile(cfg)]
@@ -287,8 +293,18 @@ def config_files_from_variant(
         print(configs)
 
     # Make sure that if the user specified a variant then that a config file for the variant exists
-    if variant is not None and not any(cfg.endswith(variant+'.conf') for cfg in configs):
-        sys.stderr.write(" ".join(["Could not find a config file for variant =",variant,".  Did you make a typo in the variant?\n"]))
+    if variant is not None and not any(
+        cfg.endswith(variant + ".conf") for cfg in configs
+    ):
+        sys.stderr.write(
+            " ".join(
+                [
+                    "Could not find a config file for variant =",
+                    variant,
+                    ".  Did you make a typo in the variant?\n",
+                ]
+            )
+        )
         if verbose >= 2:
             sys.stderr.write("\n".join(["Checked for "] + variantconfigs))
         sys.exit(1)
