@@ -1,6 +1,3 @@
-from __future__ import print_function
-from __future__ import unicode_literals
-
 import unittest
 import os
 import shutil
@@ -15,7 +12,6 @@ import ct.cake
 
 
 class TestMagicInclude(unittest.TestCase):
-
     def setUp(self):
         try:
             if self._tmpdir is not None:
@@ -31,41 +27,43 @@ class TestMagicInclude(unittest.TestCase):
                 if ct.utils.isexecutable(os.path.join(root, ff)):
                     actual_exes.add(ff)
 
-        expected_exes = {os.path.splitext(os.path.split(filename)[1])[
-            0] for filename in relativepaths if ct.utils.issource(filename)}
+        expected_exes = {
+            os.path.splitext(os.path.split(filename)[1])[0]
+            for filename in relativepaths
+            if ct.utils.issource(filename)
+        }
         self.assertSetEqual(expected_exes, actual_exes)
 
     def test_magicinclude(self):
-        # This test is to ensure that the //#INCLUDE magic flag 
+        # This test is to ensure that the //#INCLUDE magic flag
         # works to pick up subdir/important.hpp
-        # and that the --include=subdir2 subdir3 
+        # and that the --include=subdir2 subdir3
         # works to pick up subdir2/important2.hpp and subdir3/important3.hpp
 
         origdir = os.getcwd()
 
         # Copy the magicinclude test files to the temp directory and compile
         # using cake
-        tmpmagicinclude = os.path.join(self._tmpdir, 'magicinclude')
-        shutil.copytree( os.path.join(uth.samplesdir(), 'magicinclude')
-                       , tmpmagicinclude)
+        tmpmagicinclude = os.path.join(self._tmpdir, "magicinclude")
+        shutil.copytree(os.path.join(uth.samplesdir(), "magicinclude"), tmpmagicinclude)
         os.chdir(tmpmagicinclude)
 
         temp_config_name = ct.unittesthelper.create_temp_config(tmpmagicinclude)
         argv = [
-            '--exemarkers=main',
-            '--testmarkers=unittest.hpp',
-            '--CTCACHE=None',
-            '--quiet',
-            '--include=subdir2',
-            'subdir3',
-            '--auto',
-            '--config=' +
-            temp_config_name]
+            "--exemarkers=main",
+            "--testmarkers=unittest.hpp",
+            "--CTCACHE=None",
+            "--quiet",
+            "--include=subdir2",
+            "--include=subdir3",
+            "--auto",
+            "--config=" + temp_config_name,
+        ]
 
         uth.reset()
         ct.cake.main(argv)
 
-        relativepaths = ['magicinclude/main.cpp']
+        relativepaths = ["magicinclude/main.cpp"]
         self._verify_one_exe_per_main(relativepaths)
 
         # Cleanup
@@ -76,5 +74,5 @@ class TestMagicInclude(unittest.TestCase):
         uth.reset()
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     unittest.main()
